| Title: | Data Used in the Vignettes Accompanying the CARBayes and CARBayesST Packages |
|---|---|
| Description: | Spatio-temporal data from Scotland used in the vignettes accompanying the CARBayes (spatial modelling) and CARBayesST (spatio-temporal modelling) packages. Most of the data relate to the set of 271 Intermediate Zones (IZ) that make up the 2001 definition of the Greater Glasgow and Clyde health board. |
| Authors: | Duncan Lee |
| Maintainer: | Duncan Lee <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 3.0 |
| Built: | 2026-06-04 08:26:20 UTC |
| Source: | https://github.com/cran/CARBayesdata |
Spatio-temporal data from Scotland used in the vignettes accompanying the CARBayes (spatial modelling) and CARBayesST (spatio-temporal modelling) packages. Most of the data relate to the set of 271 Intermediate Zones (IZ) that make up the 2001 definition of the Greater Glasgow and Clyde health board.
| Package: | CARBayesdata |
| Type: | Package |
| Version: | 3.0 |
| Date: | 2022-05-11 |
| License: | GPL (>= 2) |
Maintainer: Duncan Lee <[email protected]>
library(sf) ## Read in the spatial data for the Greater Glasgow and Clyde Health Board data(GGHB.IZ) ## Read in the respiratory hospitalisation and pollution data data(pollutionhealthdata) ## Read in the property price data data(pricedata) ## Read in the respiratory hospitalisation data data(respiratorydata) ## Read in the property sales data data(salesdata)library(sf) ## Read in the spatial data for the Greater Glasgow and Clyde Health Board data(GGHB.IZ) ## Read in the respiratory hospitalisation and pollution data data(pollutionhealthdata) ## Read in the property price data data(pricedata) ## Read in the respiratory hospitalisation data data(respiratorydata) ## Read in the property sales data data(salesdata)
A Simple Features (sf) object containing the spatial polygon information for the set of 271 Intermediate Zones (IZ), that make up the 2001 definition of the Greater Glasgow and Clyde health board in Scotland. This study region is used in the worked examples in the vignettes accompanying the CARBayes and CARBayesST packages.
data(GGHB.IZ)data(GGHB.IZ)
A Simple Features (sf) object, which contains 271 observations on the following variables.
IZUnique code for each IZ.
nameName of each IZ.
geometryThe polygons representing each IZ.
eastingEasting coordinate of the centroid in metres.
northingNorthing coordinate of the centroid in metres.
These data were provided by the Scottish Government via http://data.gov.uk.
library(sf) data(GGHB.IZ)library(sf) data(GGHB.IZ)
These purely spatial data summarise overall lip cancer cases and possible covariate risk factors for the period 1975 to 1986, for 56 districts in Scotland. These data are used by the saeHB package.
data(lipdata)data(lipdata)
A data.frame object containing 56 observations on the following 5 variables.
observedThe number of recorded lip cancer cases.
expectedThe expected number of lip cancer cases computed using indirect standardisation using Scotland-wide disease rates.
pcaffThe percetage of the workforce employed in agriculture, fishing and forestry.
latitudeThe latitude of the centroid.
longitudeThe longitude of the centroid.
data(lipdata)data(lipdata)
A data.frame object containing spatio-temporal data on respiratory hospitalisations, air pollution concentrations and socio-economic deprivation covariates for the 271 Intermediate Zones (IZ) that make up the Greater Glasgow and Clyde health board in Scotland. Yearly data are available between 2007 and 2011 inclusive. These data are used in a worked example in the vignette accompanying the CARBayesST package.
data(pollutionhealthdata)data(pollutionhealthdata)
A data.frame object containing 1355 observations on the following 7 variables.
IZThe unique identifier for each IZ.
yearThe year the data relate to.
observedThe observed numbers of hospitalisations due to respiratory disease.
expectedThe expected numbers of hospitalisations due to respiratory disease computed using indirect standardisation from Scotland-wide respiratory hospitalisation rates.
pm10Average particulate matter (less than 10 microns) concentrations.
jsaThe percentage of working age people who are in receipt of Job Seekers Allowance, a benefit paid to unemployed people looking for work.
priceAverage property price (divided by 100,000).
These data were provided by the Scottish Government via http://statistics.gov.scot.
data(pollutionhealthdata)data(pollutionhealthdata)
A data.frame object containing purely spatial data on median property prices in 2008 and possible covariates for 270 of the 271 Intermediate Zones (IZ) that make up the Greater Glasgow and Clyde health board in Scotland. Data for one IZ have been removed due to it having an extreme outlying observation. These data are used in a worked example in the vignette accompanying the CARBayes package.
data(pricedata)data(pricedata)
A data.frame object containing 270 observations on the following 7 variables.
IZThe unique identifier for each IZ.
priceMedian property price.
crimeThe crime rate (number of crimes per 10,000 people).
roomsThe median number of rooms in a property.
salesThe percentage of properties that sold in a year.
driveshopThe average time taken to drive to a shopping centre in minutes.
typeThe predominant property type with levels:
detached, flat, semi, terrace.
These data were provided by the Scottish Government via http://statistics.gov.scot.
data(pricedata)data(pricedata)
A data.frame object containing purely spatial data on hospital admisssions due to respiratory disease in 2010 for the 134 Intermediate Zones (IZ) to the north of the river Clyde in the Greater Glasgow and Clyde health board. These data are used in a worked example in the vignette accompanying the CARBayes package.
data(respiratorydata)data(respiratorydata)
A data.frame object containing 134 observations on the following 5 variables.
IZThe unique identifier for each IZ.
observedThe observed numbers of hospitalisations due to respiratory disease.
expectedThe expected numbers of hospitalisations due to respiratory disease computed using indirect standardisation from Scotland-wide respiratory hospitalisation rates.
incomedepThe percentage of people who are defined to be income deprived.
SMRThe standardised morbidity ratio (SMR = observed / expected) for respiratory hospitalisation.
These data were provided by the Scottish Government via http://statistics.gov.scot.
data(respiratorydata)data(respiratorydata)
A data.frame object containing spatio-temporal data on property sales and the total number of properties for the 271 Intermediate Zones (IZ) that make up the Greater Glasgow and Clyde health board in Scotland. Yearly data are available between 2003 and 2013 inclusive. These data are used in a worked example in the vignette accompanying the CARBayesST package.
data(salesdata)data(salesdata)
A data.frame object containing 2981 observations on the following 4 variables.
IZThe unique identifier for each IZ.
yearThe year the data relate to.
salesThe number of property sales.
stockThe number of properties.
These data were provided by the Scottish Government via http://statistics.gov.scot.
data(salesdata)data(salesdata)